#!/bin/bash

path="/usr/share/glvnd/egl_vendor.d"
is_exist_sm750=false
is_only_integrated_gpu=true

remove_file_if_exists() {
    if [ -f "$1" ]; then
        rm "$1"
    fi
}

# Use lspci to detect GPUs
gpu_info=$(lspci -nn | grep -i "VGA compatible controller")

# Parse GPU information
while IFS= read -r line; do
    # Extract vendor and device IDs
    ids=$(echo "$line" | grep -oP '\[.*?\]' | tail -1 | tr -d '[]')
    vendor=$(echo "$ids" | cut -d: -f1)
    device=$(echo "$ids" | cut -d: -f2)

    # Check for SM750 (vendor=126f, device=0750)
    if [ "$vendor" == "126f" ] && [ "$device" == "0750" ]; then
        is_exist_sm750=true
    # Check for other GPUs (exclude Loongson integrated GPU vendor=0014)
    elif [ "$vendor" != "0014" ]; then
        is_only_integrated_gpu=false
    fi
done <<< "$gpu_info"

# Handle detected GPUs
if [ "$is_only_integrated_gpu" = false ] && [ "$is_exist_sm750" = false ]; then
    remove_file_if_exists "$path/40_loonggpu.json"
else
    # Check specifically for 7A1000 devices (vendor=0014, device=7a15 or 7a06)
    if [ "$is_only_integrated_gpu" = true ] && [ "$vendor" == "0014" ] && { [ "$device" == "7a15" ] || [ "$device" == "7a06" ]; }; then
        remove_file_if_exists "$path/40_loonggpu.json"
    else
        cp "$path/60_loonggpu.json" "$path/40_loonggpu.json"
    fi
fi
